bar_plot: Bar Plot Code

Description Usage Arguments Value

View source: R/00_Plots-Bar.R

Description

Helper function to generate bar plot based on different conditions.

Usage

1
2
3
4
5
6
bar_plot(data = NULL, df_name = NULL, x = NULL, y = NULL,
  colorby = "None", Theme = NULL, fontSize = 10,
  legendPos = "right", title_x = "", title_y = "",
  colourfill = "#00FF0080", plotTitle = "", facetRow, facetCol,
  hideAxis, axisAngle = 90, position = "", coorflip = FALSE,
  interactive = FALSE)

Arguments

data

data.frame - Passed from shiny enviornment

x

character- This is x variable for aesthitic, supplied from shiny enviornment.

y

character- This is y variable for aesthitic, supplied from shiny enviornment.

colorby

character - Parameter used to colorby plot. (defaults to None).

Theme

character- parameter to change plot theme. (defaults to None).

legendPos

character- Adjust Legend position (defaults to right)

title_x

character- Set x axis title.

title_y

character- Set y axis title.

colourfill

character- Hexcode or RGB color code for plot (defaults to #00FF0080)

plotTitle

character- Set plot title.

facetRow

character- facet column name, if faceted by Row

facetCol

character- facet column name, if faceted by Column

hideAxis

Logical - If we want to hide x Axis labels. (default: FALSE)

axisAngle

Numeric- change x tick labels angle. (default: 90)

position

character- Three Choice Stack, Fill, Dodge (Default: Stack)

coorflip

Logical- Flip Coordinates (Defaults: FALSE)

interactive

Logical- Convert to interactive plot (Defaults:FALSE)

fontsize

numeric- This parameter controls fontsize for x-y titles, x-y ticks labels. (defaults to 10).

Value

returns H2OFrame


easy-plot/ggQuickPlotR documentation built on July 22, 2020, 8:23 p.m.