scatter_plot: Bar Plot Code

Description Usage Arguments Value

View source: R/01_Plots-Scatter.R

Description

Helper function to generate bar plot based on different conditions.

Usage

1
2
3
4
5
scatter_plot(data = dt, df_name = NULL, x = NULL, y = NULL,
  Theme = NULL, colourfill = "#00FF0080", colorby = "None", shapeby,
  fontSize = 10, legendPos = "right", dotSize = 2, dotOpa = 0.7,
  title_x = "", title_y = "", plotTitle = "", hideAxis, axisAngle,
  regressionLine = FALSE, correlation = FALSE, facetRow, facetCol)

Arguments

data

data.frame - Passed from shiny enviornment

x

character- This is x variable for aesthitic, supplied from shiny enviornment.

y

character- This is y variable for aesthitic, supplied from shiny enviornment.

Theme

character- parameter to change plot theme. (defaults to None).

colourfill

character - Parameter used to colour plot.

colorby

character - Parameter used to colorby plot. (defaults to None).

legendPos

character- Adjust Legend position (defaults to right)

dotSize

numeric- Set size of dots.

dotOpa

numeric- Set opacity of dots.

title_x

character- Set x axis title.

title_y

character- Set y axis title.

plotTitle

character- Set plot title.

regressionLine

checkbox- to add regression line to plot.

correlation

checkbox- to calculate pearson correlation.

fontsize

numeric- This parameter controls fontsize for x-y titles, x-y ticks labels. (defaults to 10).

Value

returns H2OFrame


easy-plot/ggQuickPlotR documentation built on July 22, 2020, 8:23 p.m.